YARP 2.3.19 (2012-07-05)                                              {#v2_3_19}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.15...v2.3.19`):

```
    84	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    42	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
    41	Ugo Pattacini <ugo.pattacini@iit.it>
    20	Lorenzo Natale <lorenzo.natale@iit.it>
    17	Ali Paikan <ali.paikan@iit.it>
     8	Alessandro Scalzo <alessandro.scalzo@iit.it>
     8	Andrea Del Prete <andrea.delprete@iit.it>
     3	Elena Ceseracciu <elena.ceseracciu@iit.it>
     2	Marco Randazzo <marco.randazzo@iit.it>
```
